open Base
open Exceptions

module type Sig = sig
  type t

  val of_sql_row : (string * Sqlite3.Data.t) array -> t
end

module Id = struct
  type t = (string * Sqlite3.Data.t) array

  let of_sql_row = Fn.id
end

module Int64 = struct
  type t = int64

  let of_sql_row = function[@warning "-4"]
    | [| (_, Sqlite3.Data.INT x) |] -> x
    | data -> raise (Conversion_failed data)
end

module Float = struct
  type t = float

  let of_sql_row = function[@warning "-4"]
    | [| (_, Sqlite3.Data.FLOAT x) |] -> x
    | data -> raise (Conversion_failed data)
end

module String = struct
  type t = string

  let of_sql_row = function[@warning "-4"]
    | [| (_, Sqlite3.Data.TEXT s) |] -> s
    | [| (_, Sqlite3.Data.BLOB s) |] -> s
    | data -> raise (Conversion_failed data)
end
